@@ -65,6 +65,9 @@ class PybelAssembler(object):
         Copyright information for the network.
     disclaimer : str
         Any disclaimers for the network.
+    annotations_to_include : Optional[list[str]]
+        A list of evidence annotation keys that should be added to the
+        assembled PyBEL graph. Default: None
 
     Examples
     --------
@@ -83,7 +86,7 @@ class PybelAssembler(object):
     """
     def __init__(self, stmts=None, name=None, description=None, version=None,
                  authors=None, contact=None, license=None, copyright=None,
-                 disclaimer=None):
+                 disclaimer=None, annotations_to_include=None):
         if stmts is None:
             self.statements = []
         else:
@@ -123,6 +126,7 @@ class PybelAssembler(object):
         }
         self.model.namespace_url.update(ns_dict)
         self.model.namespace_pattern['PUBCHEM'] = '\d+'
+        self.annotations_to_include = annotations_to_include
 
     def add_statements(self, stmts_to_add):
         self.statements += stmts_to_add
@@ -249,6 +253,7 @@ class PybelAssembler(object):
             subj_edge=subj_edge,
             obj_edge=obj_edge,
             stmt=stmt,
+            annotations_to_include=self.annotations_to_include,
         )
         for edge_data in edge_data_list:
             self.model.add_edge(subj_data, obj_data, **edge_data)
@@ -335,13 +340,13 @@ class PybelAssembler(object):
                             zip(pybel_lists, (stmt.obj_from, stmt.obj_to)):
             for agent in agent_list:
                 node = _get_agent_grounding(agent)
-                # TODO check for missing grounding?
-                pybel_list.append(node)
-
+                if node is not None:
+                    pybel_list.append(node)
         rxn_node_data = reaction(
             reactants=pybel_lists[0],
             products=pybel_lists[1],
         )
+
         self.model.add_node_from_data(rxn_node_data)
         obj_edge = None  # TODO: Any edge information possible here?
         # Add node for controller, if there is one
@@ -353,6 +358,7 @@ class PybelAssembler(object):
                 subj_edge=subj_edge,
                 obj_edge=obj_edge,
                 stmt=stmt,
+                annotations_to_include=self.annotations_to_include,
             )
             for edge_data in edge_data_list:
                 self.model.add_edge(subj_attr, rxn_node_data, **edge_data)
@@ -435,11 +441,13 @@ def belgraph_to_signed_graph(
     return graph
 
 
-def _combine_edge_data(relation, subj_edge, obj_edge, stmt):
+def _combine_edge_data(relation, subj_edge, obj_edge, stmt,
+                       annotations_to_include=None):
     edge_data = {
         pc.RELATION: relation,
         pc.ANNOTATIONS: _get_annotations_from_stmt(stmt),
     }
+
     if subj_edge:
         edge_data[pc.SUBJECT] = subj_edge
     if obj_edge:
@@ -448,19 +456,23 @@ def _combine_edge_data(relation, subj_edge, obj_edge, stmt):
         return [edge_data]
 
     return [
-        _update_edge_data_from_evidence(evidence, edge_data)
+        _update_edge_data_from_evidence(evidence, edge_data,
+            annotations_to_include=annotations_to_include)
         for evidence in stmt.evidence
     ]
 
 
-def _update_edge_data_from_evidence(evidence, edge_data):
+def _update_edge_data_from_evidence(evidence, edge_data,
+                                    annotations_to_include=None):
     edge_data_one = copy(edge_data)
-    citation, evidence, annotations = _get_evidence(evidence)
+    citation, evidence, annotations = \
+        _get_evidence(evidence, annotations_to_include=annotations_to_include)
     edge_data_one.update({
         pc.CITATION: citation,
         pc.EVIDENCE: evidence,
     })
     edge_data_one[pc.ANNOTATIONS].update(annotations)
+
     return edge_data_one
 
 
@@ -619,7 +631,7 @@ def _get_agent_activity(agent):
     return activity(**_indra_pybel_act_map[ac.activity_type])
 
 
-def _get_evidence(evidence):
+def _get_evidence(evidence, annotations_to_include=None):
     text = evidence.text if evidence.text else 'No evidence text.'
 
     # If there is a PMID, use it as the citation
@@ -653,6 +665,41 @@ def _get_evidence(evidence):
             annotations[key] = {v: True for v in value}
         else:
             annotations[key] = {value: True}
+
+    if evidence.context:
+        context_annotations = []
+
+        attrs = ['location', 'cell_line', 'cell_type', 'organ',
+                 'disease', 'species']
+        for attr_key in attrs:
+            attr_val = evidence.context.__dict__.get(attr_key)
+            if attr_val:
+                for key, value in attr_val.db_refs.items():
+                    context_annotations.append((attr_key, f'{key}:{value}'))
+
+        # Add the annotations
+        for key, value in context_annotations:
+            annotations[key] = {value: True}
+
+    if annotations_to_include and evidence.annotations:
+        # Add the annotations
+        for annotation_key in annotations_to_include:
+            value = evidence.annotations.get(annotation_key)
+            # Skip if not in annotations or value is None
+            if not value:
+                continue
+            # For simple lists, sets, tuples, we add all the elements
+            # as annotations
+            if isinstance(value, (list, set, tuple)):
+                annotations[annotation_key] = {v: True for v in value}
+            # We don't handle dicts and skip them
+            elif isinstance(value, dict):
+                continue
+            # Otherwise, the value is a simple type like str and we use
+            # it directly
+            else:
+                annotations[annotation_key] = {value: True}
+
     return citation, text, annotations
 
 
