@@ -35,7 +35,8 @@ identifiers_mappings = {
 # identifiers.org entries
 non_registry = {
     'SDIS', 'SCHEM', 'SFAM', 'SCOMP', 'SIGNOR', 'HMS-LINCS', 'NXPFA',
-    'OMIM', 'LSPCI', 'UPLOC', 'BFO'
+    'OMIM', 'LSPCI', 'UPLOC', 'BFO', 'CCLE', 'CLO', 'GENBANK',
+    'DRUGBANK.SALT'
 }
 
 # These are namespaces that can appear in db_refs but are actually not
@@ -59,6 +60,7 @@ url_prefixes = {
     # Biology namespaces
     'NXPFA': 'https://www.nextprot.org/term/FA-',
     'SIGNOR': 'https://signor.uniroma2.it/relation_result.php?id=',
+    'LSPCI': 'https://labsyspharm.github.io/lspci/',
     # WM namespaces
     'UN': 'https://github.com/clulab/eidos/wiki/JSON-LD#Grounding/',
     'WDI': 'https://github.com/clulab/eidos/wiki/JSON-LD#Grounding/',
@@ -106,7 +108,6 @@ def get_ns_id_from_identifiers(identifiers_ns, identifiers_id):
     identifiers_id : str
         An identifiers.org standard ID in the given namespace.
 
-
     Returns
     -------
     (str, str)
@@ -278,11 +279,60 @@ def parse_identifiers_url(url):
     return None, None
 
 
+def namespace_embedded(db_ns: str) -> bool:
+    """Return true if this namespace requires IDs to have namespace embedded.
+
+    This function first maps the given namespace to an identifiers.org
+    namespace and then checks the registry to see if namespaces need
+    to be embedded in IDs. If yes, it returns True. If not, or the ID can't
+    be mapped to identifiers.org, it returns False
+
+    Parameters
+    ----------
+    db_ns :
+        The namespace to check.
+
+    Returns
+    -------
+    :
+        True if the namespace is known to be embedded in IDs of this
+        namespace. False if unknown or known not to be embedded.
+    """
+    identifiers_ns = get_identifiers_ns(db_ns)
+    if identifiers_ns:
+        identifiers_entry = identifiers_registry.get(identifiers_ns)
+        if identifiers_entry['namespace_embedded']:
+            return True
+    return False
+
+
+def ensure_prefix_if_needed(db_ns: str, db_id: str) -> str:
+    """Return an ID ensuring a namespace prefix if known to be needed.
+
+    Parameters
+    ----------
+    db_ns :
+        The namespace associated with the identifier.
+    db_id :
+        The original identifier.
+
+    Returns
+    -------
+    :
+        The identifier with namespace embedded if needed.
+    """
+    if namespace_embedded(db_ns):
+        return ensure_prefix(db_ns, db_id)
+    return db_id
+
+
 def ensure_prefix(db_ns, db_id, with_colon=True):
-    """Return a valid ID that has the appropriate prefix.
+    """Return a valid ID that has the given namespace embedded.
 
     This is useful for namespaces such as CHEBI, GO or BTO that require
-    the namespace to be part of the ID.
+    the namespace to be part of the ID. Note that this function always
+    ensures that the given db_ns is embedded in the ID and can handle the
+    case whene it's already present.
 
     Parameters
     ----------
@@ -314,4 +364,11 @@ def ensure_chembl_prefix(chembl_id):
     return ensure_prefix('CHEMBL', chembl_id, with_colon=False)
 
 
-identifiers_registry = load_resource_json('identifiers_patterns.json')
+def _load_identifiers_registry():
+    identifiers_registry = load_resource_json('identifiers_patterns.json')
+    # Override pattern otherwise patterns like 1.1 can't be used
+    identifiers_registry['ec-code']['pattern'] = '^\\d{1,2}(\\.\\d{0,3}){0,3}$'
+    return identifiers_registry
+
+
+identifiers_registry = _load_identifiers_registry()
