@@ -19,7 +19,7 @@ class BioOntology(IndraOntology):
     # should be incremented to "force" rebuilding the ontology to be consistent
     # with the underlying resource files.
     name = 'bio'
-    version = '1.12'
+    version = '1.18'
 
     def __init__(self):
         super().__init__()
@@ -64,7 +64,7 @@ class BioOntology(IndraOntology):
         self.add_drugbank_nodes()
         # Add xrefs
         logger.info('Adding xrefs...')
-        self.add_hgnc_uniprot_xrefs()
+        self.add_hgnc_uniprot_entrez_xrefs()
         self.add_hgnc_entrez_xrefs()
         self.add_famplex_xrefs()
         self.add_chemical_xrefs()
@@ -81,6 +81,9 @@ class BioOntology(IndraOntology):
         self.add_activity_hierarchy()
         self.add_modification_hierarchy()
         self.add_uppro_hierarchy()
+        self.add_lspci()
+
+        # The graph is now initialized
         self._initialized = True
         # Build name to ID lookup
         logger.info('Building name lookup...')
@@ -91,13 +94,17 @@ class BioOntology(IndraOntology):
         from indra.databases import hgnc_client
         withdrawns = set(hgnc_client.hgnc_withdrawn)
         nodes = [(self.label('HGNC', hid),
-                  {'name': hname, 'obsolete': (hid in withdrawns)})
+                  {'name': hname, 'obsolete': (hid in withdrawns),
+                   'type': _get_hgnc_type(hgnc_client, hid)})
                  for (hid, hname) in hgnc_client.hgnc_names.items()]
         self.add_nodes_from(nodes)
 
     def add_uniprot_nodes(self):
         from indra.databases import uniprot_client
-        nodes = [(self.label('UP', uid), {'name': uname})
+
+        nodes = [(self.label('UP', uid),
+                  {'name': uname,
+                   'type': _get_uniprot_type(uniprot_client, uid)})
                  for (uid, uname)
                  in uniprot_client.um.uniprot_gene_name.items()]
         self.add_nodes_from(nodes)
@@ -106,15 +113,17 @@ class BioOntology(IndraOntology):
         from indra.databases import uniprot_client
         nodes = []
         for prot_id, features in uniprot_client.um.features.items():
+            parent_type = _get_uniprot_type(uniprot_client, prot_id)
             for feature in features:
                 if feature.id is None:
                     continue
                 node = self.label('UPPRO', feature.id)
-                data = {'name': feature.name}
+                data = {'name': feature.name,
+                        'type': parent_type + '_fragment'}
                 nodes.append((node, data))
         self.add_nodes_from(nodes)
 
-    def add_hgnc_uniprot_xrefs(self):
+    def add_hgnc_uniprot_entrez_xrefs(self):
         from indra.databases import hgnc_client
         from indra.databases import uniprot_client
         edges = []
@@ -130,6 +139,14 @@ class BioOntology(IndraOntology):
                  for uid, hid in uniprot_client.um.uniprot_hgnc.items()]
         self.add_edges_from(edges)
 
+        edges = [(self.label('UP', uid), self.label('EGID', egid),
+                  {'type': 'xref', 'source': 'uniprot'})
+                 for uid, egid in uniprot_client.um.uniprot_entrez.items()]
+        edges += [(self.label('EGID', egid), self.label('UP', uid),
+                  {'type': 'xref', 'source': 'uniprot'})
+                  for egid, uid in uniprot_client.um.entrez_uniprot.items()]
+        self.add_edges_from(edges)
+
     def add_hgnc_entrez_xrefs(self):
         from indra.databases import hgnc_client
         edges = []
@@ -146,7 +163,8 @@ class BioOntology(IndraOntology):
                 os.path.join('famplex', 'entities.csv')), delimiter=','):
             entity = row[0]
             nodes.append((self.label('FPLX', entity),
-                          {'name': entity}))
+                          {'name': entity,
+                           'type': 'protein_family_complex'}))
         self.add_nodes_from(nodes)
 
     def add_famplex_hierarchy(self):
@@ -156,7 +174,7 @@ class BioOntology(IndraOntology):
                 os.path.join('famplex', 'relations.csv')), delimiter=','):
             ns1, id1, rel, ns2, id2 = row
             if ns1 == 'HGNC':
-                id1 = hgnc_client.get_hgnc_id(id1)
+                id1 = hgnc_client.get_current_hgnc_id(id1)
             edges.append((self.label(ns1, id1),
                           self.label(ns2, id2),
                           {'type': rel}))
@@ -174,31 +192,44 @@ class BioOntology(IndraOntology):
             edges.append((self.label(ref_ns, ref_id),
                           self.label('FPLX', fplx_id),
                           {'type': 'xref', 'source': 'fplx'}))
-            edges.append((self.label('FPLX', fplx_id),
-                          self.label(ref_ns, ref_id),
-                          {'type': 'xref', 'source': 'fplx'}))
+            # We avoid FPLX->MESH mappings in this direction due to
+            # species-specificity issues
+            if ref_ns != 'MESH':
+                edges.append((self.label('FPLX', fplx_id),
+                              self.label(ref_ns, ref_id),
+                              {'type': 'xref', 'source': 'fplx'}))
         self.add_edges_from(edges)
 
     def add_obo_nodes(self):
         from indra.databases import obo_client
-        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi']
+        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi', 'ido']
         nodes = []
+        type_functions = {
+            'go': _get_go_type,
+            'efo': lambda x: 'experimental_factor',
+            'hp': lambda x: 'disease',
+            'doid': lambda x: 'disease',
+            'chebi': lambda x: 'small_molecule',
+            'ido': lambda x: 'infectious_disease_concept'
+        }
         for ns in namespaces:
-            oc = obo_client.OboClient(prefix=ns)
+            oc = obo_client.OntologyClient(prefix=ns)
             for db_id, entry in oc.entries.items():
                 label = self.label(ns.upper(), db_id)
-                # There may be more general ways of doing this but this
-                # handles the special case of BFO nodes in the EFO
-                # ontology.
-                if ns == 'efo' and db_id.startswith('BFO'):
+                # Here we handle and isa relationships that point
+                # to an entry outside this ontology. The logic for recognizing
+                # these here is: if there is a : in the ID but the prefix is
+                # not for this namespace then we assume it's another namespace
+                if ':' in db_id and not db_id.startswith(ns.upper()):
                     label = db_id
                 nodes.append((label,
-                              {'name': entry['name']}))
+                              {'name': entry['name'],
+                               'type': type_functions[ns](db_id)}))
         self.add_nodes_from(nodes)
 
     def add_obo_hierarchies(self):
         from indra.databases import obo_client
-        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi']
+        namespaces = ['go', 'efo', 'hp', 'doid', 'chebi', 'ido']
         edges = []
         # Mapping various source relation types to standardized ones
         # in this ontology graph
@@ -220,20 +251,22 @@ class BioOntology(IndraOntology):
             'has_part',
         }
         for ns in namespaces:
-            oc = obo_client.OboClient(prefix=ns)
+            oc = obo_client.OntologyClient(prefix=ns)
             for db_id, entry in oc.entries.items():
                 for rel, targets in entry.get('relations', {}).items():
                     # Skip unknown relation types
                     mapped_rel = rel_mappings.get(rel)
                     if not mapped_rel:
                         continue
-                    source_label = self.label(ns.upper(), db_id)
-                    if ns == 'efo' and db_id.startswith('BFO'):
+                    if ':' in db_id and not db_id.startswith(ns.upper()):
                         source_label = db_id
+                    else:
+                        source_label = self.label(ns.upper(), db_id)
                     for target in targets:
-                        target_label = self.label(ns.upper(), target)
-                        if ns == 'efo' and target.startswith('BFO'):
+                        if ':' in target and not target.startswith(ns.upper()):
                             target_label = target
+                        else:
+                            target_label = self.label(ns.upper(), target)
                         if rel in reverse_rel:
                             av = (target_label,
                                   source_label,
@@ -255,7 +288,6 @@ class BioOntology(IndraOntology):
             (chebi_client.cas_chebi, 'CAS', 'CHEBI', True),
             (drugbank_client.drugbank_to_db, 'DRUGBANK', None, False),
             (drugbank_client.db_to_drugbank, None, 'DRUGBANK', False),
-
         ]
         edges = []
         data = {'type': 'xref', 'source': 'chebi'}
@@ -287,7 +319,8 @@ class BioOntology(IndraOntology):
     def add_mesh_nodes(self):
         from indra.databases import mesh_client
         nodes = [(self.label('MESH', mesh_id),
-                  {'name': name})
+                  {'name': name,
+                   'type': _get_mesh_type(mesh_client, mesh_id)})
                  for mesh_id, name in
                  mesh_client.mesh_id_to_name.items()]
         self.add_nodes_from(nodes)
@@ -301,6 +334,12 @@ class BioOntology(IndraOntology):
                           self.label(db_ns, db_id),
                           data))
         for (db_ns, db_id), mesh_id in mesh_client.db_to_mesh.items():
+            # There are a variety of namespaces that are being mapped to MeSH
+            # here but we specifically avoid UP and HGNC mappings since
+            # they can lead to inconsistencies in this direction due to
+            # gene vs protein and species-specificity issues.
+            if db_ns in {'UP', 'HGNC'}:
+                continue
             edges.append((self.label(db_ns, db_id),
                           self.label('MESH', mesh_id),
                           data))
@@ -428,6 +467,8 @@ class BioOntology(IndraOntology):
                 continue
             refs = lc.get_small_molecule_refs(hmsl_id)
             for ref_ns, ref_id in refs.items():
+                if ref_ns == 'HMS-LINCS':
+                    continue
                 edges.append((self.label('HMS-LINCS', hmsl_base_id),
                               self.label(ref_ns, ref_id),
                               {'type': 'xref', 'source': 'hms-lincs'}))
@@ -444,6 +485,23 @@ class BioOntology(IndraOntology):
                           {'name': db_name}))
         self.add_nodes_from(nodes)
 
+    def add_lspci(self):
+        lspci = read_unicode_csv(get_resource_path('lspci.tsv'),
+                                 delimiter='\t')
+        nodes_to_add = []
+        edges_to_add = []
+        next(lspci)
+        for (lspcid, name, members_str) in lspci:
+            label = self.label('LSPCI', lspcid)
+            nodes_to_add.append((label, {'name': name,
+                                         'type': 'small_molecule'}))
+            members = [member.split(':', maxsplit=1)
+                       for member in members_str.split('|')]
+            edges_to_add += [(self.label(*member), label, {'type': 'isa'})
+                             for member in members]
+        self.add_nodes_from(nodes_to_add)
+        self.add_edges_from(edges_to_add)
+
     def add_activity_hierarchy(self):
         rels = [
             ('transcription', 'activity'),
@@ -490,7 +548,59 @@ class BioOntology(IndraOntology):
         try:
             assert_valid_db_refs({db_ns: db_id})
         except Exception as e:
-            logger.warning('Invalid node: %s' % e)
+            logger.warning(e)
+
+
+def _get_uniprot_type(uc, uid):
+    mnem = uc.get_mnemonic(uid)
+    if mnem and mnem.endswith('HUMAN'):
+        return 'human_gene_protein'
+    else:
+        return 'nonhuman_gene_protein'
+
+
+def _get_hgnc_type(hc, hgnc_id):
+    locus_type = hc.get_gene_type(hgnc_id)
+    if locus_type == 'gene with protein product':
+        return 'human_gene_protein'
+    elif locus_type.startswith('RNA'):
+        return 'human_rna'
+    else:
+        return 'human_gene_other'
+
+def _get_go_type(go_id):
+    from indra.databases import go_client
+    go_namespace = go_client.get_namespace(go_id)
+    term_name = go_client.get_go_label(go_id)
+    if go_namespace == 'cellular_component':
+        if 'complex' in term_name:
+            return 'protein_family_complex'
+        else:
+            return 'cellular_location'
+    elif go_namespace in {'biological_process', 'molecular_function'}:
+        return 'biological_process'
+
+
+def _get_mesh_type(mesh_client, mesh_id):
+    # These subtrees under D are for proteins
+    if mesh_client.has_tree_prefix(mesh_id, 'D08') or \
+            mesh_client.has_tree_prefix(mesh_id, 'D12'):
+        return 'human_gene_protein'
+    # We classify the remainder as small molecules
+    elif mesh_client.has_tree_prefix(mesh_id, 'D'):
+        return 'small_molecule'
+    elif mesh_client.has_tree_prefix(mesh_id, 'A'):
+        return 'anatomical_region'
+    elif mesh_client.has_tree_prefix(mesh_id, 'B'):
+        return 'organism'
+    elif mesh_client.has_tree_prefix(mesh_id, 'C'):
+        return 'disease'
+    elif mesh_client.has_tree_prefix(mesh_id, 'E'):
+        return 'experimental_factor'
+    elif mesh_client.has_tree_prefix(mesh_id, 'G'):
+        return 'biological_process'
+    else:
+        return 'other'
 
 
 CACHE_DIR = os.path.join((get_config('INDRA_RESOURCES') or
