@@ -54,11 +54,12 @@ class AssemblyPipeline():
     functions referenced here have to be either imported and passed as function
     objects or registered with the @register_pipeline decorator and passed as
     function names (strings). The pipeline built this way can be optionally
-    saved into a JSON file.
+    saved into a JSON file. (Note that this example requires indra_world
+    to be installed.)
 
     >>> from indra.tools.assemble_corpus import *
-    >>> from indra.ontology.world import load_world_ontology
-    >>> from indra.belief.wm_scorer import get_eidos_scorer
+    >>> from indra_world.ontology import load_world_ontology
+    >>> from indra_world.belief import get_eidos_scorer
     >>> ap = AssemblyPipeline()
     >>> ap.append(filter_no_hypothesis)
     >>> ap.append(filter_grounded_only)
@@ -86,11 +87,9 @@ class AssemblyPipeline():
         # This import is here to avoid circular imports
         # It is enough to import one function to get all registered functions
         from indra.tools.assemble_corpus import filter_grounded_only
-        from indra.ontology.world import load_world_ontology
         from indra.ontology.bio import bio_ontology
         from indra.preassembler.grounding_mapper.gilda import ground_statements
-        from indra.belief.wm_scorer import get_eidos_scorer
-        from indra.preassembler.custom_preassembly import location_matches
+        from indra.preassembler.custom_preassembly import agent_grounding_matches
         self.steps = steps if steps else []
 
     @classmethod
