@@ -1,4 +1,5 @@
 import time
+import tqdm
 import logging
 import itertools
 import functools
@@ -7,6 +8,7 @@ import networkx as nx
 from indra.util import fast_deepcopy
 from indra.statements import *
 from indra.statements import stmt_type as indra_stmt_type
+from .refinement import *
 
 logger = logging.getLogger(__name__)
 
@@ -30,10 +32,6 @@ class Preassembler(object):
         A function which takes two Statement objects and an ontology
         as an argument and returns True or False. If supplied, it overrides
         the built-in refinement_of method of each Statement being assembled.
-    refinement_ns : Optional[set]
-        A set of name spaces that should be considered for constructing
-        refinements. If not provided, all name spaces are considered.
-        Default: None
 
     Attributes
     ----------
@@ -47,7 +45,7 @@ class Preassembler(object):
         An INDRA Ontology object.
     """
     def __init__(self, ontology, stmts=None, matches_fun=None,
-                 refinement_fun=None, refinement_ns=None):
+                 refinement_fun=None):
         self.ontology = ontology
         if stmts:
             logger.debug("Deepcopying stmts in __init__")
@@ -60,7 +58,6 @@ class Preassembler(object):
             default_matches_fun
         self.refinement_fun = refinement_fun if refinement_fun else \
             default_refinement_fun
-        self.refinement_ns = refinement_ns
         self._comparison_counter = 0
 
     def add_statements(self, stmts):
@@ -219,19 +216,20 @@ class Preassembler(object):
         The procedure for combining statements in this way involves a series
         of steps:
 
-        1. The statements are grouped by type (e.g., Phosphorylation) and
-           each type is iterated over independently.
-        2. Each statement's agents are then aligned in a role-wise manner
-           with the ontology being used, and all other statements which
-           this statement can possibly refine are found.
-        4. Each statement is then compared with the set of other statements
-           identified earlier. If the statement represents a refinement of
+        1. The statements are subjected to (built-in or user-supplied) filters
+           that group them based on potential refinement relationships. For
+           instance, the ontology-based filter positions each statement,
+           based on its agent arguments, with the ontology, and determines
+           potential refinements based on paths in the ontology graph.
+        2. Each statement is then compared with the set of statements it
+           can potentially refine, as determined by the pre-filters.
+           If the statement represents a refinement of
            the other (as defined by the `refinement_of()` method implemented
            for the Statement), then the more refined statement is added
            to the `supports` field of the more general statement, and the
            more general statement is added to the `supported_by` field of
            the more refined statement.
-        5. A new flat list of statements is created that contains only those
+        3. A new flat list of statements is created that contains only those
            statements that have no `supports` entries (statements containing
            such entries are not eliminated, because they will be retrievable
            from the `supported_by` fields of other statements). This list
@@ -251,18 +249,16 @@ class Preassembler(object):
         return_toplevel : Optional[bool]
             If True only the top level statements are returned.
             If False, all statements are returned. Default: True
-        filters : Optional[list[function]]
-            A list of function handles that define filter functions on
-            possible statement refinements. Each function takes
-            a stmts_by_hash dict and a stmts_to_compare dict as its input and
-            returns a dict of possible refinements where the keys are
-            statement hashes and the values are sets of statement hashes that
-            the key statement possibly refines. If not provided, a built-in
-            ontology-based pre-filter is applied. Note, that if a list of filter
-            functions is provided, the built-in ontology-based pre-filter is not
-            automatically appended to the list of filters. In this case,
-            consider adding the `ontology_refinement_filter` function from this
-            module to the filters list.
+        filters : Optional[list[:py:class:`indra.preassembler.refinement.RefinementFilter`]]
+            A list of RefinementFilter classes that implement filters on
+            possible statement refinements. For details on how to
+            construct such a filter, see the documentation of
+            :py:class:`indra.preassembler.refinement.RefinementFilter`.
+            If no user-supplied filters are provided, the default ontology-based
+            filter is applied. If a list of filters is provided here, the
+            :py:class:`indra.preassembler.refinement.OntologyRefinementFilter`
+            isn't appended by default, and should be added by the user, if
+            necessary. Default: None
 
         Returns
         -------
@@ -333,14 +329,18 @@ class Preassembler(object):
         split_idx : Optional[int]
             An index at which the flat list of unique statements should be split
             and compared for refinements only across the two groups, not
-            within each group.
-        filters : Optional[list[function]]
-            A list of function handles that define filter functions on
-            possible statement refinements. Each function takes
-            a stmts_by_hash dict as its input and returns a dict
-            of possible refinements where the keys are statement hashes
-            and the values are sets of statement hashes that the
-            key statement possibly refines.
+            within each group. By default, no splitting is done and all statements
+            are compared for refinements.
+        filters : Optional[list[:py:class:`indra.preassembler.refinement.RefinementFilter`]]
+            A list of RefinementFilter classes that implement filters on
+            possible statement refinements. For details on how to
+            construct such a filter, see the documentation of
+            :py:class:`indra.preassembler.refinement.RefinementFilter`.
+            If no user-supplied filters are provided, the default ontology-based
+            filter is applied. If a list of filters is provided here, the
+            :py:class:`indra.preassembler.refinement.OntologyRefinementFilter`
+            isn't appended by default, and should be added by the user, if
+            necessary. Default: None
 
         Returns
         -------
@@ -364,115 +364,52 @@ class Preassembler(object):
         # Statements keyed by their hashes
         stmts_by_hash = {stmt.get_hash(matches_fun=self.matches_fun):
                          stmt for stmt in unique_stmts}
-        stmts_to_compare = None
         # Here we apply any additional filters to cut down the number of
         # potential comparisons before actually making comparisons
-        if filters:
-            # We apply filter functions sequentially
-            for filter_fun in filters:
-                logger.debug('Applying filter %s' % filter_fun.__name__)
-                stmts_to_compare = \
-                    filter_fun(stmts_by_hash, stmts_to_compare)
-                total_comparisons = sum(len(v)
-                                        for v in stmts_to_compare.values())
-                logger.debug('Total comparisons after filter %s: %d' %
-                             (filter_fun.__name__, total_comparisons))
-        else:
-            stmts_to_compare = \
-                ontology_refinement_filter(stmts_by_hash=stmts_by_hash,
-                                           stmts_to_compare=stmts_to_compare,
-                                           ontology=self.ontology)
-        total_comparisons = sum(len(v) for v in stmts_to_compare.values())
-
-        te = time.time()
-        logger.info('Applied all refinement pre-filters in %.2fs' % (te-ts))
-        logger.info('Total comparisons: %d' % total_comparisons)
+        if not filters:
+            filters = [OntologyRefinementFilter(ontology=self.ontology)]
 
         # Here we handle split_idx to allow finding refinements between
-        # to distinct groups of statements (identified by an index at which we
+        # two distinct groups of statements (identified by an index at which we
         # split the unique_statements list) rather than globally across
         # all unique statements.
         if split_idx:
-            # This dict maps statement hashes to a bool value based on which
-            # of the two groups the statement belongs to.
-            hash_to_split_group = {sh: (idx <= split_idx) for sh, idx
-                                   in stmt_to_idx.items()}
-        else:
-            hash_to_split_group = None
+            split_groups = {sh: (idx <= split_idx)
+                            for sh, idx in stmt_to_idx.items()}
+            sgf = SplitGroupFilter(split_groups=split_groups)
+            filters.append(sgf)
 
-        # We can now do the actual comparisons and return pairs of confirmed
-        # refinements in a list.
-        maps = \
-            self.confirm_possible_refinements(stmts_by_hash,
-                                              stmts_to_compare,
-                                              split_groups=hash_to_split_group)
+        # We can now append the confirmation filter
+        confirm_filter = \
+            RefinementConfirmationFilter(ontology=self.ontology,
+                                         refinement_fun=self.refinement_fun)
+        filters.append(confirm_filter)
 
-        idx_maps = [(stmt_to_idx[refinement], stmt_to_idx[refined])
-                    for refinement, refined in maps]
-        return idx_maps
+        # Initialize all filters
+        for filt in filters:
+            filt.initialize(stmts_by_hash=stmts_by_hash)
 
-    def confirm_possible_refinements(self, stmts_by_hash, stmts_to_compare,
-                                     split_groups=None):
-        """Return confirmed pairs of statement refinement relationships.
+        # This is the core of refinement finding. Here we apply filter functions
+        # per statement, sequentially.
+        # Since the actual comparison which evaluates the refinement_fun on
+        # potentially related statements is the last filter, we don't need to
+        # do any further operations after this loop.
+        relations = {}
+        for stmt_hash, stmt in tqdm.tqdm(stmts_by_hash.items(),
+                                         desc='Finding refinement relations'):
+            relations[stmt_hash] = \
+                find_refinements_for_statement(stmt, filters)
 
-        Parameters
-        ----------
-        stmts_by_hash : dict
-            A dict whose keys are statement hashes that point to the
-            (deduplicated) statement with that hash as a value.
-        stmts_to_compare : dict
-            A dict whose keys are statement hashes and values are sets of
-            statement hashes that the statement with the given hash can
-            possibly refine.
-        split_groups : dict
-            A dict whose keys are statement hashes and values represent
-            one of two groups that the statement is in. Statement in the
-            same group aren't compared, only statements in different
-            groups are. This can be used to do "bipartite" refinement
-            checking across a set of statements.
-
-        Returns
-        -------
-        list of tuple
-            A list of tuple where the first element of each tuple is the
-            hash of a statement which refines that statement whose hash
-            is the second element of the tuple.
-        """
-        maps = []
-        # We again iterate over statements
-        ts = time.time()
-        # Given the possible refinements in stmts_to_compare, we confirm each
-        for stmt_hash, possible_refined_hashes in stmts_to_compare.items():
-            # We use the previously constructed set of statements that this one
-            # can possibly refine
-            for possible_refined_hash in possible_refined_hashes:
-                # We handle split groups here to only check refinements between
-                # statements that are in different groups to compare
-                if not split_groups or split_groups[stmt_hash] != \
-                        split_groups[possible_refined_hash]:
-                    # And then do the actual comparison. Here we use
-                    # entities_refined=True which means that we assert that
-                    # the entities, in each role, are already confirmed to
-                    # be "compatible" for refinement, and therefore, we
-                    # don't need to again confirm this (i.e., call "isa") in
-                    # the refinement_of function.
-                    self._comparison_counter += 1
-                    ref = self.refinement_fun(
-                        stmts_by_hash[stmt_hash],
-                        stmts_by_hash[possible_refined_hash],
-                        ontology=self.ontology,
-                        # NOTE: here we assume that the entities at this point
-                        # are definitely refined due to the use of an
-                        # ontology-based pre-filter. If this is not the case
-                        # for some reason then it is the responsibility of the
-                        # user-supplied self.refinement_fun to disregard the
-                        # entities_refined argument.
-                        entities_refined=True)
-                    if ref:
-                        maps.append((stmt_hash, possible_refined_hash))
         te = time.time()
-        logger.debug('Confirmed %d refinements in %.2fs' % (len(maps), te-ts))
-        return maps
+        logger.info('Found all refinements in %.2fs' % (te-ts))
+        self._comparison_counter = confirm_filter.comparison_counter
+        logger.info('Total comparisons: %d' % self._comparison_counter)
+
+        idx_maps = []
+        for refiner, refineds in relations.items():
+            idx_maps += [(stmt_to_idx[refiner], stmt_to_idx[refined])
+                         for refined in refineds]
+        return idx_maps
 
     def find_contradicts(self):
         """Return pairs of contradicting Statements.
@@ -612,6 +549,38 @@ class Preassembler(object):
         self._normalize_relations(ns, rank_key, rel_fun, True)
 
 
+def find_refinements_for_statement(stmt, filters):
+    """Return refinements for a single statement given initialized filters.
+
+    Parameters
+    ----------
+    stmt : indra.statements.Statement
+        The statement whose relations should be found.
+    filters : list[:py:class:`indra.preassembler.refinement.RefinementFilter`]
+        A list of refinement filter instances. The filters passed to this
+        function need to have been initialized with stmts_by_hash.
+
+    Returns
+    -------
+    set
+        A set of statement hashes that this statement refines.
+    """
+    first_filter = True
+    relations = {}
+    for filt in filters:
+        # The first filter outputs all the possible relations that it
+        # can find, while subsequent filters are taking the results of
+        # the previous filter as the basis of further filtering down
+        # on possible refinements.
+        possibly_related = None if first_filter else relations
+        # We pass in the specific statement and any constraints on
+        # previously determined possible relations to the filter.
+        relations = filt.get_less_specifics(stmt,
+                                            possibly_related=possibly_related)
+        first_filter = False
+    return relations
+
+
 def render_stmt_graph(statements, reduce=True, english=False, rankdir=None,
                       agent_style=None):
     """Render the statement hierarchy as a pygraphviz graph.
@@ -852,225 +821,5 @@ def _flatten_evidence_for_stmt(stmt, collect_from):
     return list(total_evidence)
 
 
-def default_refinement_fun(st1, st2, ontology, entities_refined):
-    return st1.refinement_of(st2, ontology, entities_refined)
-
-
 def default_matches_fun(st):
     return st.matches_key()
-
-
-# TODO: we could make the agent key function parameterizable with the
-# preassembler to allow custom agent mappings to the ontology.
-def get_agent_key(agent):
-    """Return a key for an Agent for use in refinement finding.
-
-    Parameters
-    ----------
-    agent : indra.statements.Agent or None
-         An INDRA Agent whose key should be returned.
-
-    Returns
-    -------
-    tuple or None
-        The key that maps the given agent to the ontology, with special
-        handling for ungrounded and None Agents.
-    """
-    if isinstance(agent, Event):
-        agent = agent.concept
-    if agent is None:
-        agent_key = None
-    else:
-        agent_key = agent.get_grounding()
-        if not agent_key[0]:
-            agent_key = ('NAME', agent.name)
-    return agent_key
-
-
-def get_relevant_keys(agent_key, all_keys_for_role, ontology):
-    """Return relevant agent keys for an agent key for refinement finding.
-
-    Parameters
-    ----------
-    agent_key : tuple or None
-        An agent key of interest.
-    all_keys_for_role : set
-        The set of all agent keys in a given statement corpus with a
-        role matching that of the given agent_key.
-    ontology : indra.ontology.IndraOntology
-        An IndraOntology instance with respect to which relevant other
-        agent keys are found for the purposes of refinement.
-
-    Returns
-    -------
-    set
-        The set of relevant agent keys which this given agent key can
-        possibly refine.
-    """
-    relevant_keys = {None, agent_key}
-    if agent_key is not None:
-        relevant_keys |= set(ontology.get_parents(*agent_key))
-    relevant_keys &= all_keys_for_role
-    return relevant_keys
-
-
-def ontology_refinement_filter(stmts_by_hash, stmts_to_compare, ontology):
-    """Return possible refinement relationships based on an ontology.
-
-    Parameters
-    ----------
-    stmts_by_hash : dict
-        A dict whose keys are statement hashes that point to the
-        (deduplicated) statement with that hash as a value.
-    stmts_to_compare : dict or None
-        A dict of existing statements to compare that will be further
-        filtered down in this function and then returned.
-    ontology : indra.ontology.IndraOntology
-        An IndraOntology instance iwth respect to which this
-        filter is applied.
-
-    Returns
-    -------
-    dict
-        A dict whose keys are statement hashes and values are sets
-        of statement hashes that can potentially be refined by the
-        statement identified by the key.
-    """
-    ts = time.time()
-    stmts_by_type = collections.defaultdict(set)
-    for stmt_hash, stmt in stmts_by_hash.items():
-        stmts_by_type[indra_stmt_type(stmt)].add(stmt_hash)
-    stmts_by_type = dict(stmts_by_type)
-
-    first_filter = stmts_to_compare is None
-    if first_filter:
-        stmts_to_compare = collections.defaultdict(set)
-    for stmt_type, stmt_hashes in stmts_by_type.items():
-        logger.info('Finding ontology-based refinements for %d %s statements'
-                    % (len(stmts_by_type[stmt_type]), stmt_type.__name__))
-        stmts_by_hash_this_type = {
-            stmt_hash: stmts_by_hash[stmt_hash]
-            for stmt_hash in stmt_hashes
-        }
-        stmts_to_compare_by_type = \
-            ontology_refinement_filter_by_stmt_type(stmts_by_hash_this_type,
-                                                    ontology)
-        if first_filter:
-            stmts_to_compare.update(stmts_to_compare_by_type)
-        else:
-            for k, v in stmts_to_compare_by_type.items():
-                stmts_to_compare[k] = stmts_to_compare[k] & v
-
-    te = time.time()
-    logger.debug('Identified ontology-based possible refinements in %.2fs'
-                 % (te-ts))
-    # Make an empty dict to make sure we don't return a None
-    if stmts_to_compare is None:
-        stmts_to_compare = {}
-    return stmts_to_compare
-
-
-def ontology_refinement_filter_by_stmt_type(stmts_by_hash, ontology):
-    """Return possible refinement relationships based on an ontology.
-
-    Importantly, here we assume that all statements in stmts_by_hash
-    are of a single type.
-
-    Parameters
-    ----------
-    stmts_by_hash : dict
-        A dict whose keys are statement hashes that point to the
-        (deduplicated) statement with that hash as a value.
-    ontology : indra.ontology.IndraOntology
-        An IndraOntology instance iwth respect to which this
-        filter is applied.
-
-    Returns
-    -------
-    list of tuple
-        A list of tuples where the first element of each tuple is the
-        hash of a statement which refines that statement whose hash
-        is the second element of the tuple.
-    """
-    # Step 1. initialize data structures
-    roles = stmts_by_hash[next(iter(stmts_by_hash))]._agent_order
-    # Mapping agent keys to statement hashes
-    agent_key_to_hash = {}
-    # Mapping statement hashes to agent keys
-    hash_to_agent_key = {}
-    # All agent keys for a given agent role
-    all_keys_by_role = {}
-    for role in roles:
-        agent_key_to_hash[role] = collections.defaultdict(set)
-        hash_to_agent_key[role] = collections.defaultdict(set)
-
-    # Step 2. Fill up the initial data structures in preparation
-    # for identifying potential refinements
-    for sh, stmt in stmts_by_hash.items():
-        for role in roles:
-            agents = getattr(stmt, role)
-            # Handle a special case here where a list=like agent
-            # role can be empty, here we will consider anything else
-            # to be a refinement, hence add a None key
-            if isinstance(agents, list) and not agents:
-                agent_keys = {None}
-            # Generally, we take all the agent keys for a single or
-            # list-like agent role.
-            else:
-                agent_keys = {get_agent_key(agent) for agent in
-                              (agents if isinstance(agents, list)
-                               else [agents])}
-            for agent_key in agent_keys:
-                agent_key_to_hash[role][agent_key].add(sh)
-                hash_to_agent_key[role][sh].add(agent_key)
-
-    agent_key_to_hash = dict(agent_key_to_hash)
-    hash_to_agent_key = dict(hash_to_agent_key)
-
-    for role in roles:
-        all_keys_by_role[role] = set(agent_key_to_hash[role].keys())
-
-    # Step 3. Identify all the pairs of statements which can be in a
-    # refinement relationship
-    stmts_to_compare = {}
-    # We iterate over each statement and find all other statements that it
-    # can potentially refine
-    ts = time.time()
-    for sh, stmt in stmts_by_hash.items():
-        relevants = None
-        # We now iterate over all the agent roles in the given statement
-        # type
-        for role, hash_to_agent_key_for_role in hash_to_agent_key.items():
-            # We get all the agent keys in all other statements that the
-            # agent
-            # in this role in this statement can be a refinement.
-            for agent_key in hash_to_agent_key_for_role[sh]:
-                relevant_keys = get_relevant_keys(
-                    agent_key,
-                    all_keys_by_role[role],
-                    ontology)
-                # We now get the actual statement hashes that these other
-                # potentially refined agent keys appear in in the given role
-                role_relevant_stmt_hashes = set.union(
-                    *[agent_key_to_hash[role][rel]
-                      for rel in relevant_keys]) - {sh}
-                # In the first iteration, we initialize the set with the
-                # relevant statement hashes
-                if relevants is None:
-                    relevants = role_relevant_stmt_hashes
-                # In subsequent iterations, we take the intersection of
-                # the relevant sets per role
-                else:
-                    relevants &= role_relevant_stmt_hashes
-        # These hashes are now the ones that this statement needs
-        # to be compared against. Importantly, the relationship is in
-        # a well-defined direction so we don't need to test both ways.
-        stmts_to_compare[sh] = relevants
-    return stmts_to_compare
-
-
-def bio_ontology_refinement_filter(stmts_by_hash, stmts_to_compare):
-    """An ontology refinement filter that works with the INDRA BioOntology."""
-    from indra.ontology.bio import bio_ontology
-    return ontology_refinement_filter(stmts_by_hash, stmts_to_compare,
-                                      ontology=bio_ontology)
