@@ -10,6 +10,7 @@ from urllib.request import urlretrieve
 from xml.etree import ElementTree as ET
 from indra.util import read_unicode_csv, write_unicode_csv
 from indra.databases.obo_client import OboClient
+from indra.databases.owl_client import OwlClient
 from indra.databases import chebi_client, pubchem_client
 from indra.databases.lincs_client import load_lincs_csv
 from . import load_resource_json, get_resource_path
@@ -51,7 +52,9 @@ def update_hgnc_entries():
     # Select relevant columns and parameters
     cols = ['gd_hgnc_id', 'gd_app_sym', 'gd_app_name', 'gd_status',
             'gd_aliases', 'md_eg_id', 'md_prot_id',
-            'md_mgd_id', 'md_rgd_id', 'gd_prev_sym', 'gd_pub_ensembl_id']
+            'md_mgd_id', 'md_rgd_id', 'gd_prev_sym', 'gd_pub_ensembl_id',
+            'gd_locus_type']
+
     statuses = ['Approved', 'Entry%20Withdrawn']
     params = {
             'hgnc_dbtag': 'on',
@@ -547,8 +550,12 @@ def update_mesh_supplementary_names():
     for record in supp_et.iterfind('SupplementalRecord'):
         uid = record.find('SupplementalRecordUI').text
         name = record.find('SupplementalRecordName/String').text
+        mapped_to_terms = record.findall('HeadingMappedToList/HeadingMappedTo/'
+                                         'DescriptorReferredTo/DescriptorUI')
+        mapped_to = ','.join([term.text.replace('*', '')
+                              for term in mapped_to_terms])
         term_name_str = _get_term_name_str(record, name)
-        supp_rows.append((uid, name, term_name_str))
+        supp_rows.append((uid, name, term_name_str, mapped_to))
 
     fname = os.path.join(path, 'mesh_supp_id_label_mappings.tsv')
     write_unicode_csv(fname, supp_rows, delimiter='\t')
@@ -642,6 +649,11 @@ def update_chebi_obo():
     OboClient.update_resource(path, url, 'chebi', remove_prefix=False)
 
 
+def update_ido():
+    """Update infectious disease ontology (IDO)."""
+    OwlClient.update_from_obo_library('ido', remove_prefix=True)
+
+
 def update_drugbank_mappings():
     """Update mappings from DrugBank to CHEBI/CHEMBL"""
     # Note that for this to work, PyOBO (https://github.com/pyobo/pyobo) has
@@ -768,6 +780,40 @@ def update_biomappings():
                       delimiter='\t')
 
 
+def update_lspci():
+    # We first create a dict of LSPCIs and their members but only for ones
+    # that actually have TAS statements corresponding to them
+    from indra.sources import tas
+    tp = tas.process_from_web(affinity_class_limit=10)
+    lspci_members = defaultdict(set)
+    for stmt in tp.statements:
+        if 'LSPCI' not in stmt.subj.db_refs:
+            continue
+        for k, v in stmt.subj.db_refs.items():
+            if k in {'TEXT', 'LSPCI'}:
+                continue
+            lspci_members[stmt.subj.db_refs.get('LSPCI')].add((k, v))
+
+    # We then process the names table in a way that we always prioritize the
+    # first row for each LSPCI since the table is pre-sorted by priority
+    df = pandas.read_csv('lsp_compound_names.csv', dtype={'lspci_id': str})
+    lspcid_names = {}
+    for _, row in df.iterrows():
+        if row['lspci_id'] not in lspcid_names:
+            lspcid_names[row['lspci_id']] = row['name']
+
+    # We can now combine the two sources filtering to only entries that have
+    # names
+    rows = [['lspcid', 'name', 'members']]
+    for lspcid, members in lspci_members.items():
+        if lspcid not in lspcid_names:
+            continue
+        row = [lspcid, lspcid_names[lspcid],
+               '|'.join(sorted(['%s:%s' % member for member in members]))]
+        rows.append(row)
+    write_unicode_csv(get_resource_path('lspci.tsv'), rows, delimiter='\t')
+
+
 def main():
     update_famplex()
     update_famplex_map()
@@ -790,8 +836,10 @@ def main():
     update_doid()
     update_efo()
     update_hpo()
+    update_ido()
     update_drugbank_mappings()
     update_identifiers_registry()
+    update_lspci()
 
 
 if __name__ == '__main__':
