@@ -64,6 +64,13 @@ _pybel_text_location_map = {
     'Conclusion': 'conclusion'
 }
 
+EXT_CITATION_PREFIXES = {
+    'DOI',
+    'BIORXIV',
+    'CHEMRXIV',
+    'AGRICOLA',
+}
+
 
 class PybelProcessor(object):
     """Extract INDRA Statements from a PyBEL Graph.
@@ -334,19 +341,23 @@ class PybelProcessor(object):
         ev_text = edge_data.get(pc.EVIDENCE)
         ev_citation = edge_data.get(pc.CITATION)
         ev_pmid = None
+        ev_ref = None
+        text_refs = {}
         if ev_citation:
             cit_type = ev_citation.namespace
             cit_ref = ev_citation.identifier
             if cit_type == pc.CITATION_TYPE_PUBMED:
                 ev_pmid = cit_ref
                 ev_ref = None
+            elif cit_type.upper() in EXT_CITATION_PREFIXES:
+                text_refs[cit_type.upper()] = cit_ref
             else:
                 ev_pmid = None
                 ev_ref = '%s: %s' % (cit_type, cit_ref)
         epistemics = {'direct': _rel_is_direct(edge_data)}
         annotations = edge_data.get(pc.ANNOTATIONS, {})
         annotations['bel'] = edge_to_bel(u_data, v_data, edge_data)
-        if ev_ref:  # FIXME what if ev_citation is Falsy?
+        if ev_ref:
             annotations['citation_ref'] = ev_ref
 
         context = extract_context(annotations, self.annot_manager)
@@ -359,7 +370,8 @@ class PybelProcessor(object):
 
         ev = Evidence(text=ev_text, pmid=ev_pmid, source_api='bel',
                       source_id=k, epistemics=epistemics,
-                      annotations=annotations, context=context)
+                      annotations=annotations, context=context,
+                      text_refs=text_refs)
         return ev
 
 
