@@ -5,6 +5,9 @@ from indra.statements.validate import assert_valid_db_refs
 from indra.ontology.standardize import standardize_db_refs, get_standard_agent
 
 
+# These mappings are only relevant for chemical-gene relations, for
+# gene-disease and chemical-disease relations, the only two types are
+# therapeutic (mapped to Inhibition) and marker/mechanism (unmapped).
 rel_mapping = {
     # Activity regulation
     'increases^activity': Activation,
@@ -39,12 +42,11 @@ rel_mapping = {
     'decreases^ribosylation': Deribosylation,
     'increases^sumoylation': Sumoylation,
     'decreases^sumoylation': Desumoylation,
-    # For gene/disease and chemical/disease effects
-    'therapeutic': Inhibition
 }
 
 
 class CTDProcessor:
+    """Parent class for CTD relation-specific processors."""
     def __init__(self, df):
         self.df = df
         self.statements = []
@@ -54,7 +56,7 @@ class CTDChemicalDiseaseProcessor(CTDProcessor):
     """Processes chemical-disease relationships from CTD."""
 
     def extract_statements(self):
-        df = self.df[self.df[5] != '']
+        df = self.df[self.df[5] == 'therapeutic']
         for _, row in tqdm.tqdm(df.iterrows(), total=len(df)):
             chem_name, chem_mesh_id, chem_cas_id, disease_name, disease_id,\
                 direct_ev, inf_gene, inf_score, omim_ids, pmids = list(row)
@@ -63,21 +65,19 @@ class CTDChemicalDiseaseProcessor(CTDProcessor):
             chem_agent = get_chemical_agent(chem_name, chem_mesh_id,
                                             chem_cas_id)
             disease_agent = get_disease_agent(disease_name, disease_id)
-            stmt_types = get_statement_types(direct_ev)
-            for rel_str, stmt_type in stmt_types.items():
-                anns = {'direct_evidence': rel_str}
-                evs = [Evidence(source_api='ctd', pmid=pmid, annotations=anns)
-                       for pmid in pmids.split('|')]
-                stmt = stmt_type(chem_agent, disease_agent,
-                                 evidence=evs)
-                self.statements.append(stmt)
+            anns = {'direct_evidence': 'therapeutic'}
+            evs = [Evidence(source_api='ctd', pmid=pmid, annotations=anns)
+                   for pmid in pmids.split('|')]
+            stmt = Inhibition(chem_agent, disease_agent,
+                              evidence=evs)
+            self.statements.append(stmt)
 
 
 class CTDGeneDiseaseProcessor(CTDProcessor):
     """Processes gene-disease relationships from CTD."""
 
     def extract_statements(self):
-        df = self.df[self.df[4] != '']
+        df = self.df[self.df[4] == 'therapeutic']
         for _, row in tqdm.tqdm(df.iterrows(), total=len(df)):
             gene_name, gene_entrez_id, disease_name, disease_id, direct_ev, \
                 inf_chem, inf_score, omim_ids, pmids = list(row)
@@ -85,14 +85,12 @@ class CTDGeneDiseaseProcessor(CTDProcessor):
                 continue
             disease_agent = get_disease_agent(disease_name, disease_id)
             gene_agent = get_gene_agent(gene_name, gene_entrez_id)
-            stmt_types = get_statement_types(direct_ev)
-            for rel_str, stmt_type in stmt_types.items():
-                anns = {'direct_evidence': rel_str}
-                evs = [Evidence(source_api='ctd', pmid=pmid, annotations=anns)
-                       for pmid in pmids.split('|')]
-                stmt = stmt_type(gene_agent, disease_agent,
-                                 evidence=evs)
-                self.statements.append(stmt)
+            anns = {'direct_evidence': 'therapeutic'}
+            evs = [Evidence(source_api='ctd', pmid=pmid, annotations=anns)
+                   for pmid in pmids.split('|')]
+            stmt = Inhibition(gene_agent, disease_agent,
+                              evidence=evs)
+            self.statements.append(stmt)
 
 
 class CTDChemicalGeneProcessor(CTDProcessor):
@@ -107,7 +105,7 @@ class CTDChemicalGeneProcessor(CTDProcessor):
             chem_agent = get_chemical_agent(chem_name, chem_mesh_id,
                                             chem_cas_id)
             gene_agent = get_gene_agent(gene_name, gene_entrez_id)
-            stmt_types = get_statement_types(rels)
+            stmt_types = self.get_statement_types(rels, chem_name, txt)
             context = get_context(organism_name, organism_tax_id)
             for rel_str, stmt_type in stmt_types.items():
                 anns = {'interaction_action': rel_str}
@@ -117,6 +115,44 @@ class CTDChemicalGeneProcessor(CTDProcessor):
                 stmt = stmt_type(chem_agent, gene_agent, evidence=evs)
                 self.statements.append(stmt)
 
+    @staticmethod
+    def get_statement_types(rel_str, chem_name, txt):
+        rels = rel_str.split('|')
+        reactions = {rel for rel in rels if 'reaction' in rel}
+        # If there is a reaction involved and the chemical is not the first
+        # element of the reaction description then it is embedded and should
+        # not be picked up here (since when there are patterns like
+        # A->[B->C], we can pick up B->C from its own separate row).
+        if reactions and not txt.startswith(chem_name):
+            return {}
+
+        # We now map the relations to INDRA Statements
+        mapped_rels = {rel: rel_mapping[rel]
+                       for rel in rels if rel in rel_mapping}
+
+        # If we have a decreases^reaction and we know that the chemical name
+        # is the first one in the description then we have something like
+        # A-|[B->C] meaning that we will have to flip the polarity to
+        # capture the fact that the reaction is decreased.
+        if 'decreases^reaction' in reactions:
+            mapped_rels = {rel: get_inverse_stmt(stmt_type)
+                           for rel, stmt_type in mapped_rels.items()}
+        return mapped_rels
+
+
+def get_inverse_stmt(stmt_type):
+    if issubclass(stmt_type, Modification):
+        return modclass_to_inverse[stmt_type]
+    elif stmt_type == Activation:
+        return Inhibition
+    elif stmt_type == Inhibition:
+        return Activation
+    elif stmt_type == IncreaseAmount:
+        return DecreaseAmount
+    elif stmt_type == DecreaseAmount:
+        return IncreaseAmount
+    raise ValueError('Unexpected statement type %s' % stmt_type)
+
 
 def get_context(organism_name, organism_tax_id):
     if not organism_tax_id:
@@ -130,11 +166,6 @@ def get_context(organism_name, organism_tax_id):
     return bc
 
 
-def get_statement_types(rel_str):
-    rels = rel_str.split('|')
-    return {rel: rel_mapping[rel] for rel in rels if rel in rel_mapping}
-
-
 def get_disease_agent(name, disease_id):
     groundings = disease_id.split('|')
     db_refs = {}
@@ -156,6 +187,4 @@ def get_chemical_agent(name, mesh_id, cas_id):
     db_refs = {'MESH': mesh_id}
     if cas_id:
         db_refs['CAS'] = cas_id
-    db_refs = standardize_db_refs(db_refs)
-    assert_valid_db_refs(db_refs)
-    return Agent(name, db_refs=db_refs)
\ No newline at end of file
+    return get_standard_agent(name, db_refs)
\ No newline at end of file
