@@ -145,6 +145,5 @@ One can then use :py:mod:`indra.sources.eidos.api.process_json_file`
 in INDRA to process the JSON-LD output files.
 """
 
-from .api import process_text, process_json_str, process_json_file, \
-    process_json, reground_texts, initialize_reader, process_json_bio, \
+from .api import initialize_reader, process_json_bio, \
     process_text_bio, process_text_bio_entities, process_json_bio_entities
