@@ -43,7 +43,10 @@ always_include = {
     'DRUGBANK:DB00305', 'HGNC:23077', 'HGNC:17347', 'EGID:27113',
     'EGID:10320', 'EGID:116986', 'EFO:0004542', 'UP:P04377',
     'CHEBI:CHEBI:136692', 'EGID:1022', 'HGNC:1778',
-    'CHEMBL:CHEMBL296468', 'UP:P41180'
+    'CHEMBL:CHEMBL296468', 'UP:P41180', 'MESH:D000077191',
+    'MESH:C475455', 'MESH:D015032', 'CHEBI:CHEBI:27363', 'CAS:7440-66-6',
+    'EGID:673', 'EGID:5594', 'EGID:5595', 'IDO:0000514', 'LSPCI:18',
+    'EGID:109880'
 }
 
 always_include_ns = {'FPLX', 'INDRA_ACTIVITIES', 'INDRA_MODS'}
