@@ -1,9 +1,8 @@
 import pickle
 from copy import deepcopy
-from collections import namedtuple
 from indra.statements import *
 from indra.tools import assemble_corpus as ac
-from indra.ontology.world import world_ontology
+
 
 a = Agent('a', db_refs={'HGNC': '1234', 'TEXT': 'a'})
 b = Agent('b', db_refs={'UP': 'P15056', 'TEXT': 'b'})
@@ -236,38 +235,6 @@ def test_run_preassembly_all_stmts():
     assert len(st_out) == 4
 
 
-def _get_extended_wm_hierarchy():
-    wo = deepcopy(world_ontology)
-    wo.initialize()
-    wo.add_edge(
-        'WM:wm/x/y/z/flooding',
-        'WM:wm/a/b/c/flooding',
-        **{'type': 'is_equal'}
-    )
-    wo.add_edge(
-        'WM:wm/a/b/c/flooding',
-        'WM:wm/x/y/z/flooding',
-        **{'type': 'is_equal'}
-    )
-    return wo
-
-
-def test_run_preassembly_concepts():
-    ont = _get_extended_wm_hierarchy()
-    rainfall = Event(Concept('rain', db_refs={
-        'WM': ('wm/concept/causal_factor/environmental/meteorologic/'
-               'precipitation/rainfall')}))
-    flooding_1 = Event(Concept('flood', db_refs={
-        'WM': 'wm/x/y/z/flooding'}))
-    flooding_2 = Event(Concept('flooding', db_refs={
-        'WM': 'wm/a/b/c/flooding'}))
-    st_out = ac.run_preassembly([
-        Influence(rainfall, flooding_1), Influence(rainfall, flooding_2)],
-        normalize_ns='WM', normalize_equivalences=True,
-        ontology=ont)
-    assert len(st_out) == 1, st_out
-
-
 def test_expand_families():
     st_out = ac.expand_families([st10])
     assert len(st_out) == 2
@@ -606,60 +573,6 @@ def test_merge_groundings():
     assert stmts[0].obj.concept.db_refs == stmts[0].subj.concept.db_refs
 
 
-def test_merge_deltas():
-    def add_annots(stmt):
-        for ev in stmt.evidence:
-            ev.annotations['subj_adjectives'] = stmt.subj.delta.adjectives
-            ev.annotations['obj_adjectives'] = stmt.obj.delta.adjectives
-            ev.annotations['subj_polarity'] = stmt.subj.delta.polarity
-            ev.annotations['obj_polarity'] = stmt.obj.delta.polarity
-        return stmt
-    # d1 = {'adjectives': ['a', 'b', 'c'], 'polarity': 1}
-    # d2 = {'adjectives': [], 'polarity': -1}
-    # d3 = {'adjectives': ['g'], 'polarity': 1}
-    # d4 = {'adjectives': ['d', 'e', 'f'], 'polarity': -1}
-    # d5 = {'adjectives': ['d'], 'polarity': None}
-    # d6 = {'adjectives': [], 'polarity': None}
-    # d7 = {'adjectives': [], 'polarity': 1}
-
-    d1 = QualitativeDelta(polarity=1, adjectives=['a', 'b', 'c'])
-    d2 = QualitativeDelta(polarity=-1, adjectives=None)
-    d3 = QualitativeDelta(polarity=1, adjectives=['g'])
-    d4 = QualitativeDelta(polarity=-1, adjectives=['d', 'e', 'f'])
-    d5 = QualitativeDelta(polarity=None, adjectives=['d'])
-    d6 = QualitativeDelta(polarity=None, adjectives=None)
-    d7 = QualitativeDelta(polarity=1, adjectives=None)
-
-    def make_ev(name, delta):
-        return Event(Concept(name), delta=delta)
-
-    stmts = [add_annots(Influence(make_ev('a', sd), make_ev('b', od),
-                                  evidence=[Evidence(source_api='eidos',
-                                                     text='%d' % idx)]))
-             for idx, (sd, od) in enumerate([(d1, d2), (d3, d4)])]
-    stmts = ac.run_preassembly(stmts, return_toplevel=True)
-    stmts = ac.merge_deltas(stmts)
-    assert stmts[0].subj.delta.polarity == 1, stmts[0].subj.delta
-    assert stmts[0].obj.delta.polarity == -1, stmts[0].obj.delta
-    assert set(stmts[0].subj.delta.adjectives) == {'a', 'b', 'c', 'g'}, \
-        stmts[0].subj.delta
-    assert set(stmts[0].obj.delta.adjectives) == {'d', 'e', 'f'}, \
-        stmts[0].obj.delta
-
-    stmts = [add_annots(Influence(make_ev('a', sd), make_ev('b', od),
-                                  evidence=[Evidence(source_api='eidos',
-                                                     text='%d' % idx)]))
-             for idx, (sd, od) in enumerate([(d1, d5), (d6, d7), (d6, d7)])]
-    stmts = ac.run_preassembly(stmts, return_toplevel=True)
-    stmts = ac.merge_deltas(stmts)
-    assert stmts[0].subj.delta.polarity is None, stmts[0].subj.delta
-    assert stmts[0].obj.delta.polarity == 1, stmts[0].obj.delta
-    assert set(stmts[0].subj.delta.adjectives) == {'a', 'b', 'c'}, \
-        stmts[0].subj.delta
-    assert set(stmts[0].obj.delta.adjectives) == {'d'}, \
-        stmts[0].obj.delta
-
-
 def test_preassemble_flatten():
     st_out = ac.run_preassembly([st1, st3, st5, st6], flatten_evidence=False)
     assert len(st_out[0].evidence) == 1
@@ -674,55 +587,6 @@ def test_preassemble_flatten():
     assert len(st_out[1].evidence) == 1
 
 
-def test_normalize_equals_opposites():
-    ont = _get_extended_wm_hierarchy()
-    flooding1 = 'wm/a/b/c/flooding'
-    flooding2 = 'wm/x/y/z/flooding'
-    # Note that as of 5/15/2020 food_insecurity and food_security aren't
-    # explicitly opposites in the ontology
-    food_insec = 'wm/concept/causal_factor/food_insecurity/food_nonaccess'
-    food_sec = 'wm/concept/causal_factor/food_security/food_access'
-
-    # Top grounding: flooding1
-    dbr = {'WM': [(flooding1, 1.0), (flooding2, 0.5), (food_insec, 0.1)]}
-    ev1 = Event(Concept('x', db_refs=dbr))
-
-    # Top grounding: food security
-    dbr = {'WM': [(food_sec, 1.0), (flooding2, 0.5)]}
-    ev2 = Event(Concept('x', db_refs=dbr),
-                delta=QualitativeDelta(polarity=1))
-
-    # Make sure that by default, things don't get normalized out
-    stmts = ac.run_preassembly([ev1, ev2], ontology=ont)
-    assert stmts[0].concept.db_refs['WM'][0][0] != \
-        stmts[0].concept.db_refs['WM'][1][0]
-
-    # Now we turn on equivalence normalization and expect
-    # that flooding1 and flooding2 have been normalized out
-    # in ev1's db_refs
-    stmts = ac.run_preassembly([ev1, ev2], normalize_equivalences=True,
-                               normalize_ns='WM',
-                               ontology=ont)
-    assert stmts[0].concept.db_refs['WM'][0][0] == \
-        stmts[0].concept.db_refs['WM'][1][0], \
-        stmts[0].concept.db_refs['WM']
-
-    # Now we turn on opposite normalization and expect that food
-    # security and insecurity will get normalized out
-    stmts = ac.run_preassembly([ev1, ev2], normalize_equivalences=True,
-                               normalize_opposites=True, normalize_ns='WM',
-                               ontology=ont)
-    assert len(stmts) == 2
-    stmts = sorted(stmts, key=lambda x: len(x.concept.db_refs['WM']),
-                   reverse=True)
-    assert len(stmts[0].concept.db_refs['WM']) == 3, stmts[0].concept.db_refs
-    # This is to check that food_insecurity was normalized to food_security
-    assert stmts[0].concept.db_refs['WM'][2][0] == \
-           stmts[1].concept.db_refs['WM'][0][0], \
-        (stmts[0].concept.db_refs['WM'],
-         stmts[1].concept.db_refs['WM'])
-
-
 def test_filter_by_curation():
     new_st1 = deepcopy(st1)
     new_ev = Evidence(text='a -> b', source_api='new')
@@ -814,3 +678,104 @@ def test_map_db_refs():
     assert regr_stmt.subj.db_refs['db2'] == 'a2'
     assert regr_stmt.obj.db_refs['db1'] == 'b1'
     assert regr_stmt.obj.db_refs['db2'] == 'B2'
+
+
+def test_strip_supports():
+    stmts = [deepcopy(st14), deepcopy(st15)]
+    assert stmts[0].supports
+    assert stmts[1].supported_by
+    no_support = ac.strip_supports(stmts)
+    assert not no_support[0].supports
+    assert not no_support[0].supported_by
+    assert not no_support[1].supports
+    assert not no_support[1].supported_by
+
+
+def test_normalize_active_forms():
+    af1 = ActiveForm(Agent('a',
+                     mods=[ModCondition('phosphorylation', 'T', 93),
+                           ModCondition('phosphorylation', 'T', 63)]),
+                     'activity', True)
+    af2 = ActiveForm(Agent('a',
+                     mods=[ModCondition('phosphorylation', 'T', 63),
+                           ModCondition('phosphorylation', 'T', 93)]),
+                     'activity', True)
+    af3 = ActiveForm(Agent('a',
+                     mods=[ModCondition('phosphorylation')]),
+                     'activity', True)
+    ph = Phosphorylation(Agent('a'), Agent('b'))
+    act = Activation(Agent('b'), Agent('a'))
+    stmts = [af1, af2, af3, ph, act]
+    norm_stmts = ac.normalize_active_forms(stmts)
+    assert len(norm_stmts) == 3
+    norm_stmt_hashes = [stmt.get_hash() for stmt in norm_stmts]
+    assert af1.get_hash() in norm_stmt_hashes
+    assert af3.get_hash() not in norm_stmt_hashes
+    assert ph.get_hash() in norm_stmt_hashes
+    assert act.get_hash() in norm_stmt_hashes
+
+
+def test_run_mechlinker():
+    # Reduce activities
+    a1 = Agent('a', location='cytoplasm')
+    a2 = Agent('a', location='nucleus')
+    af1 = ActiveForm(a1, 'activity', True)
+    af2 = ActiveForm(a2, 'kinase', True)
+    af3 = ActiveForm(a1, 'catalytic',True)
+    stmts = [af1, af2, af3]
+    stmts_out = ac.run_mechlinker(stmts, reduce_activities=True)
+    for st in stmts_out:
+        assert st.activity == 'kinase'
+    # Reduce modifications
+    phos1 = Phosphorylation(Agent('b'), Agent('a'))
+    phos2 = Phosphorylation(Agent('c'), Agent('a'), 'T')
+    phos3 = Phosphorylation(Agent('d'), Agent('a'), 'T', '143')
+    stmts = [phos1, phos2, phos3]
+    stmts_out = ac.run_mechlinker(stmts, reduce_modifications=True)
+    assert len(stmts_out) == 3
+    for st in stmts_out:
+        assert st.residue == 'T'
+        assert st.position == '143'
+    # Replace activations
+    af = ActiveForm(Agent('a', mods=[ModCondition('phosphorylation')]),
+                    'activity', True)
+    phos = Phosphorylation(Agent('b'), Agent('a'))
+    act = Activation(Agent('b'), Agent('a'))
+    stmts = [af, phos, act]
+    stmts_out = ac.run_mechlinker(stmts, replace_activations=True)
+    assert len(stmts_out) == 2
+    # Require active forms
+    af = ActiveForm(Agent('a', mods=[ModCondition('phosphorylation')]),
+                    'activity', True)
+    ph = Phosphorylation(Agent('a'), Agent('b'))
+    stmts = [af, ph]
+    stmts_out = ac.run_mechlinker(stmts, require_active_forms=True)
+    assert len(stmts_out) == 2
+    assert stmts_out[1].enz.mods, stmts_out
+
+
+def test_filter_inconsequential():
+    mc = ModCondition('phosphorylation', None, None, True)
+    phos1 = Phosphorylation(None, Agent('a'))
+    phos2 = Phosphorylation(Agent('a', mods=[mc]), Agent('b'))
+    act1 = Activation(Agent('a', activity=ActivityCondition('kinase', True)),
+                      Agent('b'), 'activity')
+    act2 = Activation(Agent('c'), Agent('a'), 'kinase')
+    stmts = [phos1, phos2, act1, act2]
+    stmts_out = ac.filter_inconsequential(stmts)
+    assert len(stmts_out) == 0, stmts_out
+    mod_whitelist = {'b': [('phosphorylation', 'S', '315')]}
+    act_whitelist = {'a': ['kinase']}
+    stmts_out = ac.filter_inconsequential(
+        stmts, acts=False, mod_whitelist=mod_whitelist)
+    assert len(stmts_out) == 3, stmts_out
+    stmts_out = ac.filter_inconsequential(stmts, mod_whitelist=mod_whitelist)
+    assert len(stmts_out) == 1, stmts_out
+    stmts_out = ac.filter_inconsequential(
+        stmts, mods=False, act_whitelist=act_whitelist)
+    assert len(stmts_out) == 3, stmts_out
+    stmts_out = ac.filter_inconsequential(stmts, act_whitelist=act_whitelist)
+    assert len(stmts_out) == 1, stmts_out
+    stmts_out = ac.filter_inconsequential(
+        stmts, mod_whitelist=mod_whitelist, act_whitelist=act_whitelist)
+    assert len(stmts_out) == 2, stmts_out
