@@ -115,3 +115,17 @@ def test_mesh_mapping():
         'D000077143'
     assert mesh_client.get_db_mapping('D000077143') == \
         ('CHEBI', 'CHEBI:4672')
+
+
+def test_supplementary_to_primary():
+    from indra.statements.validate import assert_valid_id
+    for supp, primaries in mesh_client.mesh_supp_to_primary.items():
+        for primary in primaries:
+            assert_valid_id('MESH', primary)
+    mesh_client.get_primary_mappings('C009879') == ['D011140']
+    mesh_client.get_primary_mappings('C114158') == ['D005063', 'D009942']
+
+
+def test_supplementary_tree_number():
+    tree_numbers = mesh_client.get_mesh_tree_numbers('C009879')
+    assert 'D25.720.327.782' in tree_numbers
\ No newline at end of file
