@@ -290,10 +290,10 @@ def test_drugbank_mappings():
 def test_standardize_up_isoform():
     refs = standardize_db_refs({'UP': 'Q99490'})
     assert refs == {'UP': 'Q99490', 'HGNC': '16921',
-                    'EGID': '116986', 'MESH': 'C485997'}, refs
+                    'EGID': '116986'}, refs
     refs = standardize_db_refs({'UP': 'Q99490-123'})
     assert refs == {'UP': 'Q99490-123', 'HGNC': '16921',
-                    'EGID': '116986', 'MESH': 'C485997'}, refs
+                    'EGID': '116986'}, refs
 
 
 def test_standardize_chembl():
@@ -324,10 +324,30 @@ def test_chebi_refinements():
 def test_standardize_hgnc_fplx_mesh_bug():
     refs = standardize_db_refs({'HGNC': '1514'})
     assert refs['UP'] == 'P41180'
-    assert refs['MESH'] == 'C095550'
     assert 'FPLX' not in refs
 
     refs = standardize_db_refs({'FPLX': 'Calcium_sensing_receptors'})
-    assert refs['MESH'] == 'D044169'
     assert refs['HGNC_GROUP'] == '279'
     assert 'HGNC' not in refs
+
+
+def test_ido_parents():
+    parents = bio_ontology.get_parents('IDO', '0000514')
+    assert ('IDO', '0000509') in parents
+
+
+def test_lspci():
+    assert bio_ontology.get_name('LSPCI', '18') == 'Pentane-1,5-Diamine'
+    members = bio_ontology.get_children('LSPCI', '18')
+    # These are some of the members, not all
+    expected_members = {('CAS', '462-94-2'),
+                        ('CHEBI', 'CHEBI:18127'),
+                        ('CHEMBL', 'CHEMBL119296'),
+                        ('PUBCHEM', '273')}
+    assert expected_members < set(members)
+
+
+def test_nonhuman_entrez():
+    name, db_refs = standardize_name_db_refs({'EGID': '109880'})
+    assert name == 'Braf', name
+    assert db_refs['UP'] == 'P28028', db_refs
