@@ -8,7 +8,9 @@ try:
 except ImportError:
     # Python 3
     import pickle
+
 import logging
+from typing import List
 from collections import defaultdict
 from copy import deepcopy, copy
 from indra.statements import *
@@ -18,9 +20,10 @@ from indra.pipeline import register_pipeline
 from indra.mechlinker import MechLinker
 from indra.databases import hgnc_client
 from indra.ontology.bio import bio_ontology
-from indra.ontology.world import world_ontology
 from indra.preassembler import Preassembler, flatten_evidence
 from indra.resources import get_resource_path
+from indra.statements.validate import print_validation_report
+import indra.tools.fix_invalidities
 
 
 logger = logging.getLogger(__name__)
@@ -241,78 +244,6 @@ def merge_groundings(stmts_in):
     return stmts_out
 
 
-@register_pipeline
-def merge_deltas(stmts_in):
-    """Gather and merge original Influence delta information from evidence.
-
-
-    This function is only applicable to Influence Statements that have
-    subj and obj deltas. All other statement types are passed through unchanged.
-    Polarities and adjectives for subjects and objects respectivey are
-    collected and merged by travesrsing all evidences of a Statement.
-
-    Parameters
-    ----------
-    stmts_in : list[indra.statements.Statement]
-        A list of INDRA Statements whose influence deltas should be merged.
-        These Statements are meant to have been preassembled and potentially
-        have multiple pieces of evidence.
-
-    Returns
-    -------
-    stmts_out : list[indra.statements.Statement]
-        The list of Statements now with deltas merged at the Statement
-        level.
-    """
-    stmts_out = []
-    for stmt in stmts_in:
-        # This operation is only applicable to Influences
-        if not isinstance(stmt, Influence):
-            stmts_out.append(stmt)
-            continue
-        # At this point this is guaranteed to be an Influence
-        deltas = {}
-        for role in ('subj', 'obj'):
-            for info in ('polarity', 'adjectives'):
-                key = (role, info)
-                deltas[key] = []
-                for ev in stmt.evidence:
-                    entry = ev.annotations.get('%s_%s' % key)
-                    deltas[key].append(entry if entry else None)
-        # POLARITY
-        # For polarity we need to work in pairs
-        polarity_pairs = list(zip(deltas[('subj', 'polarity')],
-                                  deltas[('obj', 'polarity')]))
-        # If we have some fully defined pairs, we take the most common one
-        both_pols = [pair for pair in polarity_pairs if pair[0] is not None and
-                     pair[1] is not None]
-        if both_pols:
-            subj_pol, obj_pol = max(set(both_pols), key=both_pols.count)
-            stmt.subj.delta.polarity = subj_pol
-            stmt.obj.delta.polarity = obj_pol
-        # Otherwise we prefer the case when at least one entry of the
-        # pair is given
-        else:
-            one_pol = [pair for pair in polarity_pairs if pair[0] is not None or
-                       pair[1] is not None]
-            if one_pol:
-                subj_pol, obj_pol = max(set(one_pol), key=one_pol.count)
-                stmt.subj.delta.polarity = subj_pol
-                stmt.obj.delta.polarity = obj_pol
-
-        # ADJECTIVES
-        for attr, role in ((stmt.subj.delta, 'subj'), (stmt.obj.delta, 'obj')):
-            all_adjectives = []
-            for adj in deltas[(role, 'adjectives')]:
-                if isinstance(adj, list):
-                    all_adjectives += adj
-                elif adj is not None:
-                    all_adjectives.append(adj)
-            attr.adjectives = all_adjectives
-        stmts_out.append(stmt)
-    return stmts_out
-
-
 @register_pipeline
 def map_sequence(stmts_in, do_methionine_offset=True,
                  do_orthology_mapping=True, do_isoform_mapping=True, **kwargs):
@@ -2125,3 +2056,210 @@ def map_db_refs(stmts_in, db_refs_map=None):
                 ag.db_refs = update_agent_db_refs(ag.db_refs, db_refs_map)
         stmts_out.append(new_stmt)
     return stmts_out
+
+
+@register_pipeline
+def strip_supports(stmts):
+    """Remove supports and supported by from statements."""
+    logger.info('Removing supports and supported by from statements')
+    for stmt in stmts:
+        stmt.supports = []
+        stmt.supported_by = []
+    return stmts
+
+
+@register_pipeline
+def normalize_active_forms(stmts_in):
+    """Run preassembly of ActiveForms only and keep other statements
+    unchanged.
+
+    This is specifically useful in the special case of mechanism linking
+    (that is run after preassembly) producing ActiveForm statements that are
+    redundant. Otherwise, general preassembly deduplicates ActiveForms
+    as expected.
+
+    Parameters
+    ----------
+    stmts_in : list[indra.statements.Statement]
+        A list of INDRA Statements among which ActiveForms should be
+        normalized.
+
+    Returns
+    -------
+    list[indra.statements.Statement]
+        A list of INDRA Statements in which ActiveForms are normalized.
+    """
+    logger.info('Normalizing ActiveForms')
+    af_stmts = filter_by_type(stmts_in, ActiveForm)
+    relevant_af_stmts = []
+    for stmt in af_stmts:
+        if (not stmt.agent.mods) and (not stmt.agent.mutations):
+            continue
+        relevant_af_stmts.append(stmt)
+    logger.info('%d relevant ActiveForms' % len(relevant_af_stmts))
+    non_af_stmts = filter_by_type(stmts_in, ActiveForm, invert=True)
+    af_stmts = run_preassembly(relevant_af_stmts)
+    stmts_out = af_stmts + non_af_stmts
+    return stmts_out
+
+
+@register_pipeline
+def run_mechlinker(
+        stmts_in, reduce_activities=False, reduce_modifications=False,
+        replace_activations=False, require_active_forms=False, implicit=False):
+    """Instantiate MechLinker and run its methods in defined order.
+
+    Parameters
+    ----------
+    stmts_in : list[indra.statements.Statement]
+        A list of INDRA Statements to run mechanism linking on.
+    reduce_activities : Optional[bool]
+        If True, agent activities are reduced to their most specific,
+        unambiguous form. Default: False
+    reduce_modifications : Optional[bool]
+        If True, agent modifications are reduced to their most specific,
+        unambiguous form. Default: False
+    replace_activations : Optional[bool]
+        If True, if there is compatible pair of Modification(X, Y) and
+        ActiveForm(Y) statements, then any Activation(X,Y) statements
+        are filtered out. Default: False
+    require_active_forms : Optional[bool]
+        If True, agents in active positions are rewritten to be in their
+        active forms. Default: False
+    implicit : Optional[bool]
+        If True, active forms of an agent are inferred from multiple statement
+        types implicitly, otherwise only explicit ActiveForm statements
+        are taken into account. Default: False
+
+    Returns
+    -------
+    list[indra.statements.Statement]
+        A list of INDRA Statements that have gone through mechanism linking.
+    """
+    ml = MechLinker(stmts_in)
+    if reduce_activities:
+        if implicit:
+            ml.gather_implicit_activities()
+        else:
+            ml.gather_explicit_activities()
+        ml.reduce_activities()
+    if reduce_modifications:
+        ml.gather_modifications()
+        ml.reduce_modifications()
+    if replace_activations:
+        if implicit:
+            ml.gather_implicit_activities()
+        else:
+            ml.gather_explicit_activities()
+        ml.replace_activations()
+    if require_active_forms:
+        if implicit:
+            ml.gather_implicit_activities()
+        else:
+            ml.gather_explicit_activities()
+        ml.require_active_forms()
+    return ml.statements
+
+
+@register_pipeline
+def filter_inconsequential(
+        stmts, mods=True, mod_whitelist=None, acts=True, act_whitelist=None):
+    """Keep filtering inconsequential modifications and activities until there
+    is nothing else to filter.
+
+    Parameters
+    ----------
+    stmts : list[indra.statements.Statement]
+        A list of INDRA Statements to filter.
+    mods : Optional[bool]
+        If True, inconsequential modifications are filtered out.
+        Default: True
+    mod_whitelist : Optional[dict]
+        A whitelist containing agent modification sites whose
+        modifications should be preserved even if no other statement
+        refers to them. The whitelist parameter is a dictionary in which
+        the key is a gene name and the value is a list of tuples of
+        (modification_type, residue, position). Example:
+        whitelist = {'MAP2K1': [('phosphorylation', 'S', '222')]}
+    acts : Optional[bool]
+        If True, inconsequential activations are filtered out.
+        Default: True
+    act_whitelist : Optional[dict]
+        A whitelist containing agent activity types which  should be preserved
+        even if no other statement refers to them.
+        The whitelist parameter is a dictionary in which
+        the key is a gene name and the value is a list of activity types.
+        Example: whitelist = {'MAP2K1': ['kinase']}
+
+    Returns
+    -------
+    list[indra.statements.Statement]
+        The filtered list of statements.
+    """
+    num_stmts = len(stmts)
+    while True:
+        if mods:
+            stmts = filter_inconsequential_mods(stmts, mod_whitelist)
+        if acts:
+            stmts = filter_inconsequential_acts(stmts, act_whitelist)
+        if num_stmts == len(stmts):
+            break
+        num_stmts = len(stmts)
+    return stmts
+
+
+@register_pipeline
+def fix_invalidities(stmts: List[Statement],
+                     in_place: bool = False,
+                     print_report_before: bool = False,
+                     print_report_after: bool = False,
+                     prior_hash_annots: bool = False) -> List[Statement]:
+    """Fix invalidities in a list of statements.
+
+    Parameters
+    ----------
+    stmts :
+        A list of statements to fix invalidities in
+    in_place :
+        If True, the statement objects are changed in place if an invalidity
+        is fixed. Otherwise, a deepcopy is done before running fixes.
+    print_report_before :
+        Run and print a validation report on the statements before running
+        fixing.
+    print_report_after :
+        Run and print a validation report on the statements after running
+        fixing to check if any issues remain that weren't handled by the
+        fixing module.
+    prior_hash_annots :
+        If True, an annotation is added to each evidence of a statement
+        with the hash of the statement prior to any fixes being applied.
+        This is useful if this function is applied as a post-processing
+        step on assembled statements and it is necessary to refer back
+        to the original hash of statements before an invalidity fix
+        here potentially changes it. Default: False
+
+    Returns
+    -------
+    :
+        The list of statements with validation issues fixed and some
+        invalid statements filtered out.
+    """
+    logger.info('Fixing invalidities in %d statements' % len(stmts))
+    if print_report_before:
+        logger.info('Any invalidities detected before fixing are printed below')
+        print_validation_report(stmts)
+    if not in_place:
+        logger.info('Making deepcopy of statements')
+        stmts = deepcopy(stmts)
+    # If desired, we add prior hash annotations to each evidence
+    if prior_hash_annots:
+        for stmt in stmts:
+            for ev in stmt.evidence:
+                ev.annotations['prior_hash'] = stmt.get_hash()
+    # And now apply the fixing function
+    stmts_out = indra.tools.fix_invalidities.fix_invalidities(stmts)
+    if print_report_after:
+        logger.info('Any remaining detected invalidities are printed below')
+        print_validation_report(stmts_out)
+    logger.info('%d statements after validity fixing' % len(stmts_out))
+    return stmts_out
