@@ -118,8 +118,8 @@ from indra.statements import Agent, Influence, Event, get_statement_by_name, \
 logger = logging.getLogger(__name__)
 
 db_sources = ['psp', 'cbn', 'pc', 'bel_lc', 'signor', 'biogrid', 'lincs_drug',
-              'tas', 'hprd', 'trrust', 'ctd', 'virhostnet', 'pe', 'drugbank',
-              'omnipath']
+              'tas', 'hprd', 'trrust', 'ctd', 'vhn', 'pe', 'drugbank',
+              'omnipath', 'conib', 'crog', 'dgi']
 
 reader_sources = ['geneways', 'tees', 'isi', 'trips', 'rlimsp', 'medscan',
                   'sparser', 'eidos', 'reach']
@@ -134,6 +134,7 @@ internal_source_mappings = {
     'virhostnet': 'vhn',
     'phosphosite': 'psp',
 }
+reverse_source_mappings = {v: k for k, v in internal_source_mappings.items()}
 
 all_sources = db_sources + reader_sources
 
